#include "e_mod_main.h"
#ifdef HAVE_AUDACIOUS_BEEPCTRL_H
#include <audacious/beepctrl.h>

int audacious_test_running(Eloquence_Face *face);
int audacious_get_session(Eloquence_Face *face);

void audacious_init_menu(E_Menu *menu, Eloquence_Face *face){
  E_Menu_Item *mi;
  
  mi = e_menu_item_new(menu);
  e_menu_item_label_set(mi, _("Play/Pause"));
  e_menu_item_callback_set(mi, audacious_control_play_pause, face);
  mi = e_menu_item_new(menu);
  e_menu_item_label_set(mi, _("Next Song"));
  e_menu_item_callback_set(mi, audacious_control_track_next, face);
  mi = e_menu_item_new(menu);
  e_menu_item_label_set(mi, _("Previous Song"));
  e_menu_item_callback_set(mi, audacious_control_track_prev, face);
/*
  mi = e_menu_item_new(menu);
  e_menu_item_label_set(mi, _("Shuffle on/off"));
  e_menu_item_callback_set(mi, audacious_control_shuffle, face);
*/
}

int audacious_update_song(Eloquence_Face *face){
  int state = audacious_test_running(face);
  
  if(state == 1){
    gint pos = xmms_remote_get_playlist_pos(face->session.id);
    face->song = xmms_remote_get_playlist_file(face->session.id, pos);

    draw_text(face);
  }
  if(state == 2){
    face->song = "Audacious has been paused";
    draw_text(face);
  }
  if(state == 3){
    face->song = "";
    draw_text(face);
  }
  if((state == 4) && (face->session.id != -1)){
    face->song = "";
    draw_text(face);
    face->recheck_timer = ecore_timer_add(SEARCH_REFRESH, audacious_get_session, face);
    face->session.id = -1;
  }
  return 1;
}

int audacious_test_running(Eloquence_Face *face){
  int state;

  if(xmms_remote_is_running(face->session.id)){
    if(xmms_remote_is_playing(face->session.id)){
      if(xmms_remote_is_paused(face->session.id)){
        return 2;
      }
      return 1;
    } 
    return 3;
  }
  return 4; 
}

int audacious_get_session(Eloquence_Face *face){
  if(face->session.id == -1)
    ecore_timer_del(face->recheck_timer);
      
  for(face->session.id = 0 ; face->session.id < 16 ; face->session.id++){
     if(xmms_remote_is_running(face->session.id)){
       return 0;
     }        
  }
  if(face->session.id != -1){
    face->session.id = 0;
  }
  return 0;
}

void audacious_control_play_pause(Eloquence_Face *face){
  if (xmms_remote_is_playing(face->session.id))
		  xmms_remote_pause(face->session.id);
  else
  		  xmms_remote_play(face->session.id);
		  
}

void audacious_control_track_next(Eloquence_Face *face){
  xmms_remote_playlist_prev(face->session.id);
}

void audacious_control_track_prev(Eloquence_Face *face){
  xmms_remote_playlist_next(face->session.id);
}

void audacious_control_vol_inc(Eloquence_Face *face){
  int volume = xmms_remote_get_main_volume(face->session.id);  

  int pos = xmms_remote_get_playlist_pos(face->session.id);
  face->song = xmms_remote_get_playlist_title(face->session.id, pos);
  sprintf(face->outbuf, "%s   --   Volume: %i%%", face->song, volume);
  face->song = face->outbuf;
  draw_text(face);
  
  xmms_remote_set_main_volume(face->session.id, volume+2);
}

void audacious_control_vol_dec(Eloquence_Face *face){
  int volume = xmms_remote_get_main_volume(face->session.id);

  int pos = xmms_remote_get_playlist_pos(face->session.id);
  face->song = xmms_remote_get_playlist_title(face->session.id, pos);
  sprintf(face->outbuf, "%s   --   Volume: %i%%", face->song, volume);
  face->song = face->outbuf;
  draw_text(face);
  
  xmms_remote_set_main_volume(face->session.id, volume-2);
}

void audacious_control_shuffle(Eloquence_Face *face){
  xmms_remote_toggle_shuffle(face->session.id);
} 


void audacious_add_file_callback(Eloquence_Face *face, 
		Evas_Object *obj, const char *emission, const char *source){
  /* Empty now, for drag'n'drop of files to play */
}
#endif
